from django.shortcuts import render, redirect, get_object_or_404
from django.http import HttpResponse, HttpResponseForbidden
from django.contrib.auth.decorators import login_required
from django.contrib import messages
from django.core.paginator import Paginator
from payments.models import Payment
from quotations.models import Quotation

@login_required
def invoices(request):
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_sales:
        if request.user.is_admin_user or request.user.is_super_user:
            quotations = Quotation.objects.all().order_by('-created_at')    # For admin and super admin, get all quotations
        else:
            # For other users (sales), filter quotations where the seller is the current user
            quotations = Quotation.objects.filter(seller=request.user).order_by('-created_at')  
        
        # Apply filters
        code = request.GET.get('code')
        if code:
            quotations = quotations.filter(qid__icontains=code)
        
        status = request.GET.get('status')
        if status:
            quotations = quotations.filter(status__icontains=status)
        
        customer_name = request.GET.get('customer_name')
        if customer_name:
            quotations = quotations.filter(customer_info__customer_name__icontains=customer_name)
        
        from_date = request.GET.get('from_date')
        to_date = request.GET.get('to_date')
        if from_date and to_date:
            quotations = quotations.filter(created_at__range=[from_date, to_date])
        
        # Pagination
        paginator = Paginator(quotations, 10)  # Show 10 quotations per page
        page_number = request.GET.get('page')
        page_obj = paginator.get_page(page_number)
        
        data = {
            "page_obj": page_obj,
        } 
        return render(request, "sales/invoice/index.html", data)
    else:
        return HttpResponseForbidden("You are not authorized to view this page.")

from django.shortcuts import render, get_object_or_404
from django.contrib.auth.decorators import login_required
from django.http import HttpResponseForbidden
from quotations.models import Quotation, Inquiry, CustomerQuoteInfo

@login_required
def invoice_details(request, quotation_id):
    # Check if the user has permission to view the invoice details
    if request.user.is_admin_user or request.user.is_super_user or request.user.is_sales:
        # Get the quotation object or return 404 if not found
        quotation = get_object_or_404(Quotation, pk=quotation_id)

        # Get inquiries related to this quotation
        inquiries = Inquiry.objects.filter(quotation=quotation)

        # Get customer quote info related to this quotation
        customer_quote_info = CustomerQuoteInfo.objects.filter(quotation=quotation).first()

        # Get payments related to this quotation
        payments = Payment.objects.filter(quotation=quotation)

        # Prepare the data to pass to the template
        data = {
            'quotation': quotation,
            'inquiries': inquiries,
            'customer_quote_info': customer_quote_info,
            'payments': payments,
        }

        # Render the template with the data
        return render(request, 'sales/invoice/invoice_detail.html', data)
    else:
        # If the user is not authorized, return HTTP 403 Forbidden
        return HttpResponseForbidden("You are not authorized to view this page.")
